Description Usage Arguments Examples
Create an input group of numeric inputs that function as a range input.
1 2 | numericRangeInput(inputId, label, value, width = NULL,
separator = " to ")
|
inputId |
The |
label |
Display label for the control, or |
value |
The initial value(s) for the range. A numeric vector of length one will be duplicated to represent the minimum and maximum of the range; a numeric vector of two or more will have its minimum and maximum set the minimum and maximum of the range. |
width |
The width of the input, e.g. |
separator |
String to display between the start and end input boxes. |
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 | ## Not run:
if (interactive()) {
### examples ----
# see ?demoNumericRange
demoNumericRange()
### basic usage ----
library( shiny )
library( shinyRange )
ui <- fluidPage(
tags$br(),
numericRangeInput(
inputId = "noui1", label = "Numeric Range Input:",
value = c(100, 400)
),
verbatimTextOutput(outputId = "res1")
)
server <- function(input, output, session) {
output$res1 <- renderPrint(input$noui1)
}
shinyApp(ui, server)
}
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.